import { Button, IconButton, Paper, Typography } from "@mui/material";
import Table from "@mui/material/Table";
import TableBody from "@mui/material/TableBody";
import TableCell from "@mui/material/TableCell";
import TableContainer from "@mui/material/TableContainer";
import TableHead from "@mui/material/TableHead";
import TableRow from "@mui/material/TableRow";
import EditIcon from "@mui/icons-material/Edit";
import AddCircleOutlineIcon from "@mui/icons-material/AddCircleOutline";
import { MyTableProps } from "./types";

export default function MyTable<T extends object & { id: number }>({
  config,
  data,
  onNewItem,
  onEditItem,
}: MyTableProps<T>) {
  return (
    <TableContainer component={Paper}>
      <Table sx={{ minWidth: 600 }}>
        <TableHead>
          <TableRow>
            {config.map((item) => (
              <TableCell key={item.heading}>{item.heading}</TableCell>
            ))}
            <TableCell>Actions</TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {!data.length ? (
            <TableRow>
              <TableCell colSpan={config.length + 1} align="center">
                <Typography>There are no entries yet!</Typography>
              </TableCell>
            </TableRow>
          ) : (
            data.map((row, rowIndex) => (
              <TableRow
                key={Math.random()} // N.B. For the example purposes only!!!
                sx={{ "&:last-child td, &:last-child th": { border: 0 } }}
              >
                {config.map((cell) => {
                  let content = data[rowIndex][cell.keyInData] as string;
                  if (typeof content === 'boolean') {
                    content = content ? 'Yes' : 'No';
                  }
                  return (
                    <TableCell key={cell.heading}>
                      {content}
                    </TableCell>
                  )
                })}
                <TableCell>
                  <IconButton onClick={() => onEditItem(row.id)}>
                    <EditIcon color="primary" />
                  </IconButton>
                </TableCell>
              </TableRow>
            ))
          )}
          <TableRow>
            <TableCell colSpan={config.length + 1} align="center" padding="none">
              <Button
                startIcon={<AddCircleOutlineIcon />}
                sx={{ width: "100%" }}
                onClick={onNewItem}
              >
                NEW ENTRY
              </Button>
            </TableCell>
          </TableRow>
        </TableBody>
      </Table>
    </TableContainer>
  );
}
