import { Checkbox, FormControlLabel, TextField } from '@mui/material';
import { Controller } from 'react-hook-form';
import { UpsertDialogInputProps } from './types';

export default function UpsertDialogInput<T>({
    type = 'text',
    configItem,
    hasErrors,
    register,
    control,
    ...props
}: UpsertDialogInputProps<T>) {
    const placeholder = configItem.placeholder + (configItem.options?.required ? ' *' : '');
    switch (type) {
        case 'text':
            return (
                <TextField
                    label={placeholder}
                    placeholder={placeholder}
                    error={hasErrors}
                    margin="dense"
                    fullWidth
                    {...register(configItem.name, configItem.options)} // <-- `register` function!
                    {...props}
                />
            );
        case 'checkbox':
            return (
                <Controller
                    control={control} // <-- `control` instance!
                    name={configItem.name}
                    rules={configItem.options}
                    render={({ field }) => (
                        <FormControlLabel
                            control={(
                                <Checkbox
                                    value={field.value ?? false}
                                    checked={field.value ?? false}
                                    onChange={() => field.onChange(!field.value)}
                                    {...props}
                                />
                            )}
                            label={placeholder}
                        />
                    )}
                />
            );
        default:
            throw new Error(`Unknown type: ${type}`);
    }
}
