import { Control, RegisterOptions, UseFormRegister } from "react-hook-form";

export type UpsertDialogProps<T> = {
    title?: string;
    inputConfig: UpsertDialogInputConfig<T> | null;
    isOpen: boolean;
    onSubmit: (data: any) => void;
    onClose: () => void;
};


export type UpsertDialogInputConfig<T> = Array<{
  name: string;
  options?: RegisterOptions;

  type?: "text" | "checkbox";
  placeholder: string;

  initialValue?: T[keyof T];
}>;


export type UpsertDialogInputProps<T> = {
    type?: 'text' | 'checkbox';
    configItem: UpsertDialogInputConfig<T>[number];
    hasErrors: boolean;
    register: UseFormRegister<any>;
    control: Control<any>;
};

export type UpsertDialogState<T> = {
    config: UpsertDialogInputConfig<T> | null;
    id: boolean | string | number;
};

export type UseUpsertDialog<T> = {
    title?: string;
    inputConfig: UpsertDialogInputConfig<T>;
    getInitialData: (itemId: string | number | boolean) => Promise<T | undefined>;
    onSubmit: (
      itemId: string | number | boolean,
      data: T
    ) => Promise<void>;
};
